@@ -1,26 +1,26 @@
-""" 
+"""
  @file
  @brief This file loads the clip cutting interface (quickly cut up a clip into smaller clips)
   @author Jonathan Thomas <jonathan@openshot.org>
- 
+
  @section LICENSE
- 
- Copyright (c) 2008-2016 OpenShot Studios, LLC
+
+ Copyright (c) 2008-2018 OpenShot Studios, LLC
  (http://www.openshotstudios.com). This file is part of
  OpenShot Video Editor (http://www.openshot.org), an open-source project
  dedicated to delivering high quality video editing and animation solutions
  to the world.
- 
+
  OpenShot Video Editor is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.
- 
+
  OpenShot Video Editor is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
- 
+
  You should have received a copy of the GNU General Public License
  along with OpenShot Library.  If not, see <http://www.gnu.org/licenses/>.
  """
@@ -34,18 +34,14 @@ from PyQt5.QtCore import *
 from PyQt5.QtWidgets import *
 import openshot  # Python module for libopenshot (required video editing module installed separately)
 
-from classes import info, ui_util, settings, qt_types, updates
+from classes import info, ui_util, time_parts, settings, qt_types, updates
 from classes.app import get_app
 from classes.logger import log
 from classes.metrics import *
 from windows.preview_thread import PreviewParent
 from windows.video_widget import VideoWidget
 
-try:
-    import json
-except ImportError:
-    import simplejson as json
-
+import json
 
 class Cutting(QDialog):
     """ Cutting Dialog """
@@ -105,9 +101,18 @@ class Cutting(QDialog):
         # Open video file with Reader
         log.info(self.file_path)
 
+        # Add Video Widget
+        self.videoPreview = VideoWidget()
+        self.videoPreview.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.Expanding)
+        self.verticalLayout.insertWidget(0, self.videoPreview)
+
+        # Set max size of video preview (for speed)
+        viewport_rect = self.videoPreview.centeredViewport(self.videoPreview.width(), self.videoPreview.height())
+
         # Create an instance of a libopenshot Timeline object
-        self.r = openshot.Timeline(self.width, self.height, openshot.Fraction(self.fps_num, self.fps_den), self.sample_rate, self.channels, self.channel_layout)
+        self.r = openshot.Timeline(self.videoPreview.width(), self.videoPreview.height(), openshot.Fraction(self.fps_num, self.fps_den), self.sample_rate, self.channels, self.channel_layout)
         self.r.info.channel_layout = self.channel_layout
+        self.r.SetMaxSize(viewport_rect.width(), viewport_rect.height())
 
         try:
             # Add clip for current preview file
@@ -120,6 +125,9 @@ class Cutting(QDialog):
             # Set has_audio property
             self.r.info.has_audio = self.clip.Reader().info.has_audio
 
+            # Update video_length property of the Timeline object
+            self.r.info.video_length = self.video_length
+
             if preview:
                 # Display frame #'s during preview
                 self.clip.display = openshot.FRAME_DISPLAY_CLIP
@@ -129,15 +137,6 @@ class Cutting(QDialog):
             log.error('Failed to load media file into preview player: %s' % self.file_path)
             return
 
-        # Add Video Widget
-        self.videoPreview = VideoWidget()
-        self.videoPreview.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.Expanding)
-        self.verticalLayout.insertWidget(0, self.videoPreview)
-
-        # Set max size of video preview (for speed)
-        viewport_rect = self.videoPreview.centeredViewport(self.videoPreview.width(), self.videoPreview.height())
-        self.r.SetMaxSize(viewport_rect.width(), viewport_rect.height())
-
         # Open reader
         self.r.Open()
 
@@ -191,7 +190,7 @@ class Cutting(QDialog):
         seconds = (frame_number-1) / self.fps
 
         # Convert seconds to time stamp
-        time_text = self.secondsToTime(seconds, self.fps_num, self.fps_den)
+        time_text = time_parts.secondsToTime(seconds, self.fps_num, self.fps_den)
         timestamp = "%s:%s:%s:%s" % (time_text["hour"], time_text["min"], time_text["sec"], time_text["frame"])
 
         # Update label
@@ -214,6 +213,9 @@ class Cutting(QDialog):
             ui_util.setup_icon(self, self.btnPlay, "actionPlay", "media-playback-start")  # to default
             self.preview_thread.Pause()
 
+        # Send focus back to toolbar
+        self.sliderVideo.setFocus()
+
     def sliderVideo_valueChanged(self, new_frame):
         if self.preview_thread and not self.sliderIgnoreSignal:
             log.info('sliderVideo_valueChanged')
@@ -247,7 +249,7 @@ class Cutting(QDialog):
 
         # Save thumbnail image
         self.start_image = os.path.join(info.USER_PATH, 'thumbnail', '%s.png' % self.start_frame)
-        self.r.GetFrame(self.start_frame).Thumbnail(self.start_image, 160, 90, '', '', '#000000', True)
+        self.r.GetFrame(self.start_frame).Thumbnail(self.start_image, 160, 90, '', '', '#000000', True, 'png', 85)
 
         # Set CSS on button
         self.btnStart.setStyleSheet('background-image: url(%s);' % self.start_image.replace('\\', '/'))
@@ -256,6 +258,9 @@ class Cutting(QDialog):
         self.btnEnd.setEnabled(True)
         self.btnClear.setEnabled(True)
 
+        # Send focus back to toolbar
+        self.sliderVideo.setFocus()
+
         log.info('btnStart_clicked, current frame: %s' % self.start_frame)
 
     def btnEnd_clicked(self):
@@ -281,7 +286,7 @@ class Cutting(QDialog):
 
         # Save thumbnail image
         self.end_image = os.path.join(info.USER_PATH, 'thumbnail', '%s.png' % self.end_frame)
-        self.r.GetFrame(self.end_frame).Thumbnail(self.end_image, 160, 90, '', '', '#000000', True)
+        self.r.GetFrame(self.end_frame).Thumbnail(self.end_image, 160, 90, '', '', '#000000', True, 'png', 85)
 
         # Set CSS on button
         self.btnEnd.setStyleSheet('background-image: url(%s);' % self.end_image.replace('\\', '/'))
@@ -289,6 +294,9 @@ class Cutting(QDialog):
         # Enable create button
         self.btnAddClip.setEnabled(True)
 
+        # Send focus back to toolbar
+        self.sliderVideo.setFocus()
+
         log.info('btnEnd_clicked, current frame: %s' % self.end_frame)
 
     def btnClear_clicked(self):
@@ -337,27 +345,6 @@ class Cutting(QDialog):
         # Reset form
         self.clearForm()
 
-    def padNumber(self, value, pad_length):
-        format_mask = '%%0%sd' % pad_length
-        return format_mask % value
-
-    def secondsToTime(self, secs, fps_num, fps_den):
-        # calculate time of playhead
-        milliseconds = secs * 1000
-        sec = math.floor(milliseconds/1000)
-        milli = milliseconds % 1000
-        min = math.floor(sec/60)
-        sec = sec % 60
-        hour = math.floor(min/60)
-        min = min % 60
-        day = math.floor(hour/24)
-        hour = hour % 24
-        week = math.floor(day/7)
-        day = day % 7
-
-        frame = round((milli / 1000.0) * (fps_num / fps_den)) + 1
-        return { "week":self.padNumber(week,2), "day":self.padNumber(day,2), "hour":self.padNumber(hour,2), "min":self.padNumber(min,2), "sec":self.padNumber(sec,2), "milli":self.padNumber(milli,2), "frame":self.padNumber(frame,2) };
-
     # TODO: Remove these 4 methods
     def accept(self):
         """ Ok button clicked """
